@@ -17,7 +17,7 @@ class GenericPkPass
     KITINERARY_PROPERTY(QString, name, setName)
     KITINERARY_PROPERTY(QString, pkpassPassTypeIdentifier, setPkpassPassTypeIdentifier)
     KITINERARY_PROPERTY(QString, pkpassSerialNumber, setPkpassSerialNumber)
-    KITINERARY_PROPERTY(QDateTime, validUnitl, setValidUntil)
+    KITINERARY_PROPERTY(QDateTime, validUntil, setValidUntil)
 private:
     QExplicitlySharedDataPointer<GenericPkPassPrivate> d;
 };
